@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# (c) Copyright 2014,
+# (c) Copyright 2015,
 # National Instruments Corporation.
 # All rights reserved.
 #
@@ -14,7 +14,7 @@
 #
 
 nikalDir="`cat /etc/natinst/nikal/nikal.dir`"
-nikaliVersion=14.0.0b3
+nikaliVersion=15.0.1f0
 statusSuccess=0
 statusSuccessReboot=1
 statusFail=2
@@ -27,24 +27,27 @@ nikaliPreInstall()
 
 nikaliPostInstall()
 {
-   if ! /usr/local/bin/updateNIDrivers --no-prompt; then
-      return $statusFail
-   fi
+mkdir -p /usr/local/sbin
+if ! /usr/local/bin/updateNIDrivers --no-prompt; then
+   return $statusFail
+fi
+
    return $statusSuccess
 }
 
 
 nikaliPreUninstall()
 {
-   cd "$nikalDir"/src/client
-   make clean
-   cd - > /dev/null 2>&1
+for kalmod in /lib/modules/*/kernel/natinst/nikal/nikal.ko; do
+   rm -f ${kalmod}
+   rmdir -p $(dirname ${kalmod}) 2>&1 > /dev/null
+done
+
+rm -f /usr/local/sbin/nidevnode
+rm -rf /var/lib/nikal
+
+/sbin/depmod
 
-   cd "$nikalDir"/src/nikal
-   make clean
-   make uninstall
-   rm -f Makefile.in
-   cd - > /dev/null 2>&1
    return $statusSuccess
 }
 
